@@ -6,7 +6,7 @@ use Carp;
 
 use WebService::IdoitAPI;
 
-our $VERSION = '0.4.3'; # VERSION
+our $VERSION = '0.4.4'; # VERSION
 
 sub create {
     my ($api, $fields) = @_;
@@ -82,6 +82,8 @@ sub list {
             {   id => $_->{id},
                 address => $_->{categories}->{C__CATS__NET}->[0]->{address},
                 cidr_suffix => $_->{categories}->{C__CATS__NET}->[0]->{cidr_suffix},
+                gateway => $_->{categories}->{C__CATS__NET}->[0]->{gateway}->{ref_title} || '',
+                gateway_id => $_->{categories}->{C__CATS__NET}->[0]->{gateway}->{id} || '',
             }
         } @{$res->{content}->{result}};
     }
@@ -98,7 +100,7 @@ WebService::IdoitAPI::Layer3Net - handle layer 3 networks
 
 =head1 VERSION
 
-version 0.4.3
+version 0.4.4
 
 =head1 SYNOPSIS
 
@@ -161,14 +163,18 @@ Every item in this array has the following structure:
 
   {
     id => $id,
-    network => $address,
+    address => $address,
     cidr_suffix => $suffix,
+    gateway => $gateway_addr,
+    gateway_id => $gw_id,
   }
 
 C<$id> can be used to retrieve details from i-doit
 about the network in question.
 C<$address> is the network address,
 and C<$suffix> is the CIDR suffix of the network.
+C<$gateway> is the address of the gateway or the empty string,
+C<$gateway_id> is the id of the object acting as gateway or the empty string.
 
 =head1 DIAGNOSTICS
 
